function [Y,t]=tren_impulsos2(Fs,F,Tf)
%-----------------------------------------------------------------
%  Esta funcion genera un tren de impulsos de 
%  amplitud unitaria, con las siguientes caracteristicas:
%  	Fs: frecuencia de muestreo
%  	F:  frecuencia del tren de impulsos
%  	t:  vector tiempo (intervalo de muestreo = 1/Fs)
%   	Y:  vector conteniendo el tren de impulsos
%     El tiempo total del tren de impulsos será de Tf ± una 
%     cantidad tal que entren una cantidad entera de impulsos
%----------------------------------------------------------------
%  Uso:
%		[Y,t]=tren_impulsos(Fs,F,Tf)
%----------------------------------------------------------------
%  Lucas Terissi  - 31/10/2003.
%----------------------------------------------------------------
T=[0:1/Fs:Tf]';
N=length(T);
L=floor(Fs/F);
y=[1;zeros(L-1,1)];
m=round(N/L);
Y=[];
for k=1:m
   Y=[Y;y];
end
ny=length(Y);
%Y=[Y;[1;zeros(N-ny-1,1)]];
%t=[0:1/Fs:(length(Y)-1)/Fs]';
t=[0:1/Fs:(ny-1)/Fs]';
%plot(t,Y)